Class: Nylas::JobStatus
- Inherits:
-
Object
- Object
- Nylas::JobStatus
- Includes:
- Model
- Defined in:
- lib/nylas/job_status.rb
Overview
Ruby representation of a Nylas Job Status object
Direct Known Subclasses
Instance Attribute Summary
Attributes included from Model
Instance Method Summary collapse
-
#successful? ⇒ Boolean
Returns the status of a job as a boolean.
Methods included from Model
#auth_method, #create, #destroy, #execute, included, #model_class, #persisted?, #reload, #resource_path, #resources_path, #save, #save_all_attributes, #to_json, #update, #update_all_attributes
Instance Method Details
#successful? ⇒ Boolean
Returns the status of a job as a boolean
22 23 24 |
# File 'lib/nylas/job_status.rb', line 22 def successful? status == "successful" end |