Class: Nylas::Registry::MissingKeyError
Overview
Used to indicate an attempt to retrieve something not yet registered in a registry Includes the list of keys in the registry for debug purposes.
Instance Attribute Summary collapse
-
#key ⇒ Object
Returns the value of attribute key.
Instance Method Summary collapse
-
#initialize(key, keys) ⇒ MissingKeyError
constructor
A new instance of MissingKeyError.
Constructor Details
#initialize(key, keys) ⇒ MissingKeyError
Returns a new instance of MissingKeyError.
12 13 14 15 |
# File 'lib/nylas/registry.rb', line 12 def initialize(key, keys) super("key #{key} not in #{keys}") self.key = key end |
Instance Attribute Details
#key ⇒ Object
Returns the value of attribute key.
10 11 12 |
# File 'lib/nylas/registry.rb', line 10 def key @key end |