Class: Nylas::TimeSlot
- Inherits:
-
Object
- Object
- Nylas::TimeSlot
- Includes:
- Model::Attributable
- Defined in:
- lib/nylas/time_slot.rb
Overview
Query free/busy information for a calendar during a certain time period
Query free/busy information for a calendar during a certain time period