Class: Nylas::TokenInfo

Inherits:
Object
  • Object
show all
Includes:
Model::Attributable
Defined in:
lib/nylas/token_info.rb

Overview

Structure to represent information about a Nylas access token.

Instance Method Summary collapse

Methods included from Model::Attributable

#attributes, included, #initialize, #to_h

Instance Method Details

#valid?Boolean

Returns the state of the token as a boolean

Returns:

  • (Boolean)

    If the token is active



16
17
18
# File 'lib/nylas/token_info.rb', line 16

def valid?
  state == "valid"
end