Class: Nylas::Registry::MissingKeyError

Inherits:
Error
  • Object
show all
Defined in:
lib/nylas/registry.rb

Overview

Used to indicate an attempt to retrieve something not yet registered in a registry Includes the list of keys in the registry for debug purposes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(key, keys) ⇒ MissingKeyError

Returns a new instance of MissingKeyError.



12
13
14
15
# File 'lib/nylas/registry.rb', line 12

def initialize(key, keys)
  super("key #{key} not in #{keys}")
  self.key = key
end

Instance Attribute Details

#keyObject

Returns the value of attribute key.



10
11
12
# File 'lib/nylas/registry.rb', line 10

def key
  @key
end