Class: Nylas::TokenInfo
- Inherits:
-
Object
- Object
- Nylas::TokenInfo
- Includes:
- Model::Attributable
- Defined in:
- lib/nylas/token_info.rb
Overview
Structure to represent information about a Nylas access token.
Instance Method Summary collapse
-
#valid? ⇒ Boolean
Returns the state of the token as a boolean.
Methods included from Model::Attributable
#attributes, included, #initialize, #to_h
Instance Method Details
#valid? ⇒ Boolean
Returns the state of the token as a boolean
16 17 18 |
# File 'lib/nylas/token_info.rb', line 16 def valid? state == "valid" end |